@@ -11,18 +11,14 @@
 #'
 cr_convert <- function(cr = NULL){
 
-  # Error out if its not filled
-  if(base::is.null(cr))
-    stop("`cr` must be provided")
-
-  # Error out for unrecognized challenge rating entries
-  if(!cr %in% c(0, "1/8", "1/4", "1/2", 0.125, 0.25, 0.5, 1:30))
-    stop("Unrecognized `cr` entry. Must be one of '0', '1/8', '1/4', '1/2' or any number between 1 and 30")
+  # Challenge rating must be specified as a single value in the supported set
+  if(is.null(cr) || length(cr) != 1 || cr %in% c(0, "1/8", "1/4", "1/2", 0.125, 0.25, 0.5, 1:30) != TRUE)
+    stop("'cr' must be one of '0', '1/8', '1/4', '1/2' or any number between 1 and 30")
 
   # Handle fraction CRs
-  if(cr == "1/8"){cr <- 0.125}
-  if(cr == "1/4"){cr <- 0.25}
-  if(cr == "1/2"){cr <- 0.5}
+  if(cr == "1/8"){ cr <- 1/8 }
+  if(cr == "1/4"){ cr <- 1/4 }
+  if(cr == "1/2"){ cr <- 1/2 }
 
   # Calculate XP depending on XP > / < than 20
   ## CR less than or equal to 20
