@@ -10,23 +10,27 @@
 #'
 #' @examples
 #' # Create some information for an NPC
-#' npc_creator(npc_count = 1)
+#' dndR::npc_creator(npc_count = 1)
 #'
 npc_creator <- function(npc_count = 1){
 
-  # Error out if count isn't a number
-  if(is.numeric(npc_count) != TRUE)
-    stop("`npc_count` must be numeric")
-
+  # NPC count must be a single number
+  if(is.null(npc_count) || is.numeric(npc_count) != TRUE || length(npc_count) != 1)
+    stop("'npc_count' must be specified as a single number")
+  
+  # Make sure count is an integer
+  npc_count <- round(x = npc_count, digits = 0)
+  
   # Pick a race
-  npc_race <- sample(x = dndR::dnd_races(), size = npc_count)
+  npc_race <- sample(x = dndR::dnd_races(), size = npc_count, replace = TRUE)
 
   # Pick a career
   npc_role <- sample(x = c("acolyte", "adventurer", "ambassador", "anthropologist", "archaeologist", "artisan", "barber", "bounty hunter", "caravan driver", "caravan guard", "carpenter", "charlatan", "city watch", "criminal", "diplomat", "doctor", "farmer", "farrier", "entertainer", "gladiator", "hermit", "initiate", "inquisitor", "investigator", "knight", "mercenary", "merchant", "navigator", "noble", "outlander", "sage", "scholar", "smith", "soldier", "spy", "student of magic", "smuggler", "urchin", "veteran"),
-                     size = npc_count)
+                     size = npc_count, replace = TRUE)
 
   # Assemble into named vector
-  npc_info <- data.frame("Race" = npc_race, "Job" = npc_role)
+  npc_info <- data.frame("race" = npc_race, 
+                         "job" = npc_role)
 
   # Return the data.frame
   return(npc_info) }
