@@ -12,19 +12,29 @@
 #'
 #' @examples
 #' # Roll your desired dice
-#' roll(dice = "4d6", show_dice = TRUE)
+#' dndR::roll(dice = "4d6", show_dice = TRUE)
 #'
 #' # Returned as a number so you can add rolls together or integers
-#' roll(dice = '1d20') + 5
+#' dndR::roll(dice = '1d20') + 5
 #'
 #' # Can also re-roll ones if desired
-#' roll(dice = '4d4', re_roll = TRUE)
+#' dndR::roll(dice = '4d4', re_roll = TRUE)
 #'
 roll <- function(dice = "d20", show_dice = FALSE, re_roll = FALSE){
 
-  # Error out if not a character
-  if(!is.character(dice))
-    stop("`dice` must be specified as a character (e.g., '3d8')")
+  # Dice must be provided as a single character
+  if(is.null(dice) || is.character(dice) != TRUE || length(dice) != 1 || stringr::str_detect(string = dice, pattern = "d") != TRUE)
+    stop("'dice' must be specified as a character with a lowercase 'd' between the number of dice and the number of sides of that die type (e.g., '3d8')")
+  
+  # Warn and coerce to default if logical arguments are not correct
+  ## 'show_dice'
+  if(is.logical(show_dice) != TRUE){
+    warning("'show_dice' must be a logical. Coercing to FALSE")
+    show_dice <- FALSE }
+  ## 'reroll'
+  if(is.logical(re_roll) != TRUE){
+    warning("'re_roll' must be a logical. Coercing to FALSE")
+    re_roll <- FALSE }
 
   # Identify number of dice to roll
   dice_count <- base::gsub(pattern = "d", replacement = "",
@@ -32,18 +42,18 @@ roll <- function(dice = "d20", show_dice = FALSE, re_roll = FALSE){
                                      pattern = "[:digit:]{1,10000000}d"))
 
   # If number is left blank, assume one but print warning
-  if(base::nchar(dice_count) == 0 | is.na(dice_count)){
-    base::message("Number of dice unspecified, assuming 1")
+  if(nchar(dice_count) == 0 | is.na(dice_count)){
+    message("Number of dice unspecified, assuming 1")
     dice_count <- 1 }
 
   # Identify which dice type
   dice_type <- stringr::str_extract(string = dice, pattern = "d[:digit:]{1,3}")
 
   # Identify number of dice faces (i.e., drop "d")
-  dice_faces <- base::as.numeric(base::gsub(pattern = "d", replacement = "", x = dice_type))
+  dice_faces <- as.numeric(gsub(pattern = "d", replacement = "", x = dice_type))
 
   # Roll the specified type of dice the specified number of times
-  results <- base::sample(x = 1:dice_faces, size = dice_count, replace = TRUE)
+  results <- sample(x = 1:dice_faces, size = dice_count, replace = TRUE)
 
   # If re-rolling is desired, do so here
   if(re_roll == TRUE & 1 %in% results){
@@ -54,13 +64,13 @@ roll <- function(dice = "d20", show_dice = FALSE, re_roll = FALSE){
   total <- base::sum(results, na.rm = TRUE)
 
   # If two d20 are rolled, assume they're rolling for advantage/disadvantage and don't sum
-  if(dice_type == "d20" & dice_count == 2){
+  if(dice == "2d20"){
     total <- base::data.frame('roll_1' = results[1], 'roll_2' = results[2])
-    base::message("Assuming you're rolling for (dis)advantage so both rolls returned") }
+    message("Assuming you're rolling for (dis)advantage so both rolls returned") }
 
   # If desired (and necessary), message the individual roll values
   if(show_dice == TRUE & dice_count > 1 & dice != "2d20"){
-    base::message("Individual rolls: ", paste(results, collapse = ", ")) }
+    message("Individual rolls: ", paste(results, collapse = ", ")) }
 
   # Return total
   return(total) }
